% ---------------------------------
% author: acadlore_latexstudio
% website: https://www.acadlore.com/
% date: 2023-04-12 09:14:03
% email: latex@acadlore.com
% ---------------------------------

\NeedsTeXFormat{LaTeX2e}[1999/12/01]
\ProvidesClass{acadlore}[2023/04/12, v1.0 by latexstudio.net]

\newif\if@linenumberon\global\@linenumberonfalse%
\DeclareOption{lineno}{\global\@linenumberontrue}%
\newif\if@submission\global\@submissiontrue%
\newif\if@final\global\@finalfalse%
% \newif\if@update\global\@updatefalse%
\newif\ifAPA\global\APAfalse%
\DeclareOption{submit}{\global\@submissiontrue\global\@linenumberontrue\global\@finalfalse}%
% \DeclareOption{update}{\global\@updatetrue}%
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[oneside,a4paper,10pt]{article}


\if@linenumberon
\RequirePackage[mathlines]{lineno}
\fi

\RequirePackage{
  amsmath,
  amsthm,
  booktabs,
  caption,
  enumitem,
  expl3,
  etoolbox,
  fancyhdr,
  fontawesome,
  geometry,
  graphicx,
  hyperref,
  indentfirst,
  layout,
  makecell,
  multirow,
  newtxtext,
  subfigure,
  titlesec,
  url,
  xcolor,
  xparse
}

\if@linenumberon
  %% Patch 'normal' math environments:
  \newcommand*\linenomathpatch[1]{%
    \cspreto{#1}{\linenomath}%
    \cspreto{#1*}{\linenomath}%
    \csappto{end#1}{\endlinenomath}%
    \csappto{end#1*}{\endlinenomath}%
  }
  %% Patch AMS math environments:
  \newcommand*\linenomathpatchAMS[1]{%
    \cspreto{#1}{\linenomathAMS}%
    \cspreto{#1*}{\linenomathAMS}%
    \csappto{end#1}{\endlinenomath}%
    \csappto{end#1*}{\endlinenomath}%
  }

  %% Definition of \linenomathAMS depends on whether the mathlines option is provided
  \expandafter\ifx\linenomath\linenomathWithnumbers
    \let\linenomathAMS\linenomathWithnumbers
    %% The following line gets rid of an extra line numbers at the bottom:
    \patchcmd\linenomathAMS{\advance\postdisplaypenalty\linenopenalty}{}{}{}
  \else
    \let\linenomathAMS\linenomathNonumbers
  \fi

  \linenomathpatch{equation}
  \linenomathpatchAMS{gather}
  \linenomathpatchAMS{multline}
  \linenomathpatchAMS{align}
  \linenomathpatchAMS{alignat}
  \linenomathpatchAMS{flalign}
  \if@submission
  \linespread{1.3}\selectfont
  \fi
\fi

\def\UrlBreaks{%
\do\/%
\do\a\do\b\do\c\do\d\do\e\do\f\do\g\do\h\do\i\do\j\do\k\do\l%
\do\m\do\n\do\o\do\p\do\q\do\r\do\s\do\t\do\u\do\v\do\w\do\x\do\y\do\z%
\do\A\do\B\do\C\do\D\do\E\do\F\do\G\do\H\do\I\do\J\do\K\do\L%
\do\M\do\N\do\O\do\P\do\Q\do\R\do\S\do\T\do\U\do\V\do\W\do\X\do\Y\do\Z%
\do0\do1\do2\do3\do4\do5\do6\do7\do8\do9\do=\do/\do.\do:%
\do\*\do\-\do\~\do\'\do\"\do\-}
\Urlmuskip=0mu plus 0.1mu

\definecolor{citecolor}{HTML}{0562C1}
\aboverulesep 1pt
\belowrulesep 1pt

\geometry{
  includehead,
  hmargin  = {24mm,24mm},
  vmargin  = {15mm,25mm},
  headsep  = 6mm,
  footskip = 15mm,
}

\graphicspath{{logo/},{figs/},{figures/},{fig/}}

\setlist{nosep}

\def\note #1 {{\fontsize{8pt}{8pt}\selectfont #1}}

\captionsetup{
  justification = centering,
  labelfont     = bf,
  labelsep      = period
}

\let\addr\textsuperscript

\newtheoremstyle{acadlore}{3pt}{3pt}{ }{\parindent}{\bfseries }{}{.5em}{\thmname{#1}\thmnumber{#2}\thmnote{\bfseries {#3}}.}

\theoremstyle{acadlore}
\newtheorem{theorem}{Theorem}
\newtheorem{definition}{Definition}
\newtheorem{limitation}{Limitation}

\renewenvironment{proof}[1][\proofname]{\par
  \pushQED{}%
  \normalfont \topsep3\p@\@plus6\p@\relax
  \trivlist
  \item[\hspace*{\parindent}\hskip\labelsep
        \bfseries
    #1\@addpunct{.}]\ignorespaces
}{%
  \popQED\endtrivlist\@endpefalse
}

\urlstyle{same}

\ExplSyntaxOn

\int_new:N \g__cacdlore_type_int

\keys_define:nn { cacdlore } {
  type .choice:,
  type .value_required:n = true,
  type .choices:nn =
    {ATAIML, ATAMS, ATG, ESM, IDA, IJKIS, JBCC,
     JCGIRM, JCHE, JEMSE, JGELCD, JII, JIMD, JISC,
     JOSA, JSE, JUDM, MITS, OCS, PEET, REES, empty}
    { \int_set_eq:NN \g__cacdlore_type_int \l_keys_choice_int },
  type .initial:n = ATAIML,
  abstract   . tl_set:N = \l_cacdlore_abstract_tl,
  accepted   . tl_set:N = \l_cacdlore_accepted_tl,
  address    . tl_set:N = \l_cacdlore_address_tl,
  author     . tl_set:N = \l_cacdlore_author_tl,
  citeauthor . tl_set:N = \l_cacdlore_citeauthor_tl,
  copyright  . tl_set:N = \l_cacdlore_copyright_tl,
  corrauthor . tl_set:N = \l_cacdlore_corrauthor_tl,
  doi        . tl_set:N = \l_cacdlore_doi_tl,
  journal    . tl_set:N = \l_cacdlore_journal_tl,
  journalabb . tl_set:N = \l_cacdlore_journalabb_tl,
  keywords   . tl_set:N = \l_cacdlore_keywords_tl,
  number     . tl_set:N = \l_cacdlore_number_tl,
  received   . tl_set:N = \l_cacdlore_received_tl,
  revised    . tl_set:N = \l_cacdlore_revised_tl,
  runtitle   . tl_set:N = \l_cacdlore_runtitle_tl,
  title      . tl_set:N = \l_cacdlore_title_tl,
  updates    . tl_set:N = \l_cacdlore_updates_tl,
  volume     . tl_set:N = \l_cacdlore_volume_tl,
  website    . tl_set:N = \l_cacdlore_website_tl,
  year       . tl_set:N = \l_cacdlore_year_tl,
}

\tl_set:Nn \l_cacdlore_copyright_tl {\faCopyright\ \l_cacdlore_year_tl\ by~ the~ author(s).~ Published~ by~ Acadlore~ Publishing~ Services~ Limited,~ Hong~ Kong. ~This~ article~ is~ available~ for~ free~ download~ and~ can~ be~ reused~ and~ cited, ~provided~ that~ the~ original~ published~ version~ is~ credited,~ under~ the~ CC~ BY~ 4.0~ license.}

\fancypagestyle{main}{
  \fancyhf{}
  \renewcommand{\headrulewidth}{0pt}
  \renewcommand{\footrulewidth}{0pt}
  \fancyfoot[C]{\bfseries\thepage}
}
\fancypagestyle{title}{
  \fancyhf{}
  \renewcommand{\headrulewidth}{0pt}
  \renewcommand{\footrulewidth}{0pt}
  \fancyfoot[L]{\raisebox{1.7em}{\url{https://doi.org/\g__journal_doipre_tl\l_cacdlore_doi_tl}}}
  \fancyfoot[C]{\bfseries\thepage}
}

\clist_new:N \l__journal_clist
\clist_new:N \l__journal_shorter_clist

\clist_set:Nn \l__journal_clist
{
  {ATAIML}{ataiml}
    {Acadlore~ Transactions~ on~ AI~ and~ Machine~ Learning}
    {Acadlore~ Trans.~ Mach.~ Learn.}
    {1},
  {ATAMS}{atams}
    {Acadlore~ Transactions~ on~ Applied~ Mathematics~ and~ Statistics}
    {Acadlore~ Trans.~ Appl~ Math.~ Stat.}
    {1},
  {ATG}{atg}
    {Acadlore~ Transactions~ on~ Geosciences}
    {Acadlore~ Trans.~ Geosci.}
    {1},
  {ESM}{esm}
    {Education~ Science~ and~ Management}
    {Educ~ Sci.~ Manag.}
    {0},
  {IDA}{ida}
    {Information~ Dynamics~ and~ Applications}
    {Inf.~ Dyn.~ Appl.}
    {1},
  {IJKIS}{ijkis}
    {International~ Journal~ of~ Knowledge~ and~ Innovation~ Studies}
    {Int~ J.~ Knowl.~ Innov~ Stud.}
    {1},
  {JBCC}{jbcc}
    {Journal~ of~ Buildings~ Climate~ Control}
    {J.~ Build.~ Clim.~ Control.}
    {1},
  {JCGIRM}{jcgirm}
    {Journal~ of~ Corporate~ Governance,~ Insurance,~ and~ Risk~ Management}
    {J.~ Corp.~ Gov.~ Insur.~ Risk~ Manag.}
    {0},
  {JCHE}{jche}
    {Journal~ of~ Civil~ and~ Hydraulic~ Engineering}
    {J.~ Civ.~ Hydraul.~ Eng.}
    {1},
  {JEMSE}{jemse}
    {Journal~ of~ Engineering~ Management~ and~ Systems~ Engineering}
    {J.~ Eng.~ Manag.~ Syst.~ Eng.}
    {1},
  {JGELCD}{jgelcd}
    {Journal~ of~ Green~ Economy~ and~ Low-Carbon~ Development}
    {J.~ Green~ Econ.~ Low-Carbon~ Dev.}
    {1},
  {JII}{jii}
    {Journal~ of~ Industrial~ Intelligence}
    {J.~ Ind~ Intell.}
    {1},
  {JIMD}{jimd}
    {Journal~ of~ Intelligent~ Management~ Decision}
    {J.~ Intell~ Manag.~ Decis.}
    {1},
  {JISC}{jisc}
    {Journal~ of~ Intelligent~ Systems~ and~ Control}
    {J.~ Intell~ Syst.~ Control}
    {1},
  {JOSA}{josa}
    {Journal~ of~ Operational~ and~ Strategic~ Analytics}
    {J.~ Oper.~ Strateg~ Anal.}
    {1},
  {JSE}{jse}
    {Journal~ of~ Sustainability~ for~ Energy}
    {J.~ Sustain.~ Energy}
    {1},
  {JUDM}{judm}
    {Journal~ of~ Urban~ Development~ and~ Management}
    {J.~ Urban~ Dev.~ Manag.}
    {1},
  {MITS}{mits}
    {Mechatronics~ and~ Intelligent~ Transportation~ Systems}
    {Mechatron.~ Intell~ Transp.~ Syst.}
    {1},
  {OCS}{ocs}
    {Opportunities~ and~ Challenges~ in~ Sustainability}
    {Oppor~ Chall.~ Sustain.}
    {0},
  {PEET}{peet}
    {Power~ Engineering~ and~ Engineering~ Thermophysics}
    {Power~ Eng.~ Eng.~ Thermophys.}
    {1},
  {REES}{rees}
    {Renewable~ Energy~ and~ Energy~ Storage}
    {Renew~ Energ.~ Energ~ Storage}
    {1},
  {empty}{xx}
    {Journal~ Title}
    {Journal~ title~ abbreviation}
    {1}
}

\cs_set_protected:Npn \l__journal_set:nnnn #1#2#3#4#5 {
  \clist_put_right:Nn \l__journal_shorter_clist {#1}
  \tl_set:cn { l__journal_ #1 _shorter_tl } { #1 }
  \tl_set:cn { l__journal_ #1 _doipre_tl } { 10.56578/ #2 }
  \tl_set:cn { l__journal_ #1 _long_tl } { #3 }
  \tl_set:cn { l__journal_ #1 _short_tl } { #4 }
  \tl_set:cn { l__journal_ #1 _website_tl } {https://www.acadlore.com/journals/ #1 }
  \tl_set:cn { l__journal_ #1 _refstyle_tl } { #5 }
}

\clist_map_inline:Nn \l__journal_clist { \l__journal_set:nnnn #1 }

\AtEndPreamble{
  \tl_set_eq:cc {g__journal_shorter_tl}{l__journal_ \clist_item:Nn \l__journal_shorter_clist {\g__cacdlore_type_int} _shorter_tl}
  \tl_set_eq:cc {g__journal_long_tl}{l__journal_ \clist_item:Nn \l__journal_shorter_clist {\g__cacdlore_type_int} _long_tl}
  \tl_set_eq:cc {g__journal_short_tl}{l__journal_ \clist_item:Nn \l__journal_shorter_clist {\g__cacdlore_type_int} _short_tl}
  \tl_set_eq:cc {g__journal_website_tl}{l__journal_ \clist_item:Nn \l__journal_shorter_clist {\g__cacdlore_type_int} _website_tl}
  \tl_set_eq:cc {g__journal_refstyle_tl}{l__journal_ \clist_item:Nn \l__journal_shorter_clist {\g__cacdlore_type_int} _refstyle_tl}
  \tl_set_eq:cc {g__journal_doipre_tl}{l__journal_ \clist_item:Nn \l__journal_shorter_clist {\g__cacdlore_type_int} _doipre_tl}
  \tl_set_eq:NN \journalname \g__journal_long_tl
  \int_case:nn {\tl_use:N\g__journal_refstyle_tl}
  {
    {0}{\global\APAtrue}
    {1}{\global\APAfalse}
  }
  \ifAPA
    \RequirePackage{natbib}
    \bibliographystyle{acadlore-author-year}
  \else
    \RequirePackage[numbers, sort&compress]{natbib}
    \bibliographystyle{acadlore-number}
  \fi
  \bibsep 1pt
}
\AtEndDocument{\label{LastPage}}

\NewDocumentCommand\articlesetup{ +m }{
  \keys_set:nn{cacdlore}{#1}
}

\coffin_new:N \l__rule_coffin
\coffin_new:N \l__title_coffin
\coffin_new:N \l__logoa_coffin
\coffin_new:N \l__logob_coffin
\coffin_new:N \l__updates_coffin
\coffin_new:N \l__journal_coffin
\coffin_new:N \l__website_coffin
\coffin_new:N \l__CreativeCommons_coffin
\coffin_new:N \l__copyright_coffin
\dim_new:N \l__sep_dim

\cs_set_protected:Npn \l__updates:n #1 {
  \href{https\c_colon_str//crossmark.crossref.org/dialog/?doi=\g__journal_doipre_tl#1&domain=pdf}{\includegraphics[width=10.16mm]{checkupdate}}
}

\cs_set_protected:Npn \__title_style:
{
  \hcoffin_set:Nn \l__rule_coffin { \rule{\linewidth}{3pt} }
  \vcoffin_set:Nnn \l__title_coffin {\linewidth - 18mm} { \fontsize{14pt}{14pt} \bfseries \l_cacdlore_title_tl }
  \hcoffin_set:Nn \l__logoa_coffin { {\color{white}\rule{10.5mm}{10.5mm}} }
  \hcoffin_set:Nn \l__logob_coffin { \includegraphics[height=10.5mm]{logo.pdf} }
  \hcoffin_set:Nn \l__updates_coffin { {\color{white}\rule{10.5mm}{10.5mm}} }
  \hcoffin_set:Nn \l__journal_coffin {\fontsize{12pt}{12pt}\selectfont\bfseries \g__journal_long_tl }
  \dim_compare:nNnT {\coffin_wd:N \l__journal_coffin + \coffin_wd:N \l__logoa_coffin +\coffin_wd:N \l__logob_coffin +5mm}>{\linewidth}{\hcoffin_set:Nn \l__journal_coffin {\fontsize{12pt}{12pt}\selectfont\bfseries \parbox{.6\linewidth}{\centering\g__journal_long_tl\par} }}
  \hcoffin_set:Nn \l__website_coffin {\fontsize{8pt}{8pt}\selectfont \url{\g__journal_website_tl} }
  \coffin_join:NnnNnnnn
  \l__journal_coffin {hc}{b}
  \l__website_coffin {hc}{t}
  {0pt}{-4pt}
  \dim_set:Nn \l__sep_dim {\linewidth - \coffin_wd:N \l__logoa_coffin - \coffin_wd:N \l__logob_coffin - \coffin_wd:N \l__journal_coffin}
  \coffin_join:NnnNnnnn
  \l__journal_coffin {l}{b}
  \l__logoa_coffin {r}{b}
  {-\l__sep_dim / 2}{0pt}
  \coffin_join:NnnNnnnn
  \l__journal_coffin {r}{b}
  \l__logob_coffin {l}{b}
  {\l__sep_dim / 2}{0pt}
  \coffin_join:NnnNnnnn
  \l__journal_coffin {hc}{b}
  \l__rule_coffin {hc}{t}
  {0pt}{-3pt}
  \dim_set:Nn \l_tmpa_dim {\linewidth - \coffin_wd:N \l__title_coffin - \coffin_wd:N \l__updates_coffin}
  \dim_set:Nn \l_tmpb_dim {\coffin_ht:N \l__updates_coffin}
  \coffin_typeset:Nnnnn \l__journal_coffin {l}{t}{0pt}{7pt}
  \vskip 8pt
}

\cs_set_protected:Npn \l__orcid:n #1 {\href{https\c_colon_str//orcid.org/#1}{\raisebox{.3em}{\includegraphics[width=.6em]{logo-orcid}}}}

\cs_set_eq:NN \orcid \l__orcid:n

\cs_set_protected:Nn \l__citation_stylea: {
  \textbf{Citation:}~ \l_cacdlore_citeauthor_tl,~ ``\l_cacdlore_title_tl,''~ \textit{\g__journal_short_tl},~
  vol.~ \l_cacdlore_volume_tl,~
  no.~ \l_cacdlore_number_tl,~
  pp.~ \thepage--\pageref{LastPage},~
  \l_cacdlore_year_tl.~
  \url{https://doi.org/\g__journal_doipre_tl\l_cacdlore_doi_tl}.
}

\cs_set_protected:Nn \l__citation_styleb: {
  \textbf{Citation:}~ \l_cacdlore_citeauthor_tl.~
  (\l_cacdlore_year_tl).~
  \l_cacdlore_title_tl.~ \textit{\g__journal_short_tl},~
  \l_cacdlore_volume_tl (\l_cacdlore_number_tl),~
  \thepage--\pageref{LastPage},~
  \url{https://doi.org/\g__journal_doipre_tl\l_cacdlore_doi_tl}.
}

\cs_set_protected:Npn \__maketitle:
{
  \pagestyle{main}
  \thispagestyle{title}
  \begingroup
  \hypersetup{linkcolor = black}
  \parindent 0pt
  \__title_style: \par
  {\fontsize{14pt}{14pt}\bfseries \l_cacdlore_title_tl}\par \vskip 10pt
  {\l_cacdlore_author_tl}\par \vskip 10pt
  {\def\sep{\\}\l_cacdlore_address_tl}\par \vskip 10pt
  {\addr{*}\;Correspondence:~ \l_cacdlore_corrauthor_tl}\par \vskip 10pt
  \if@final
  \textbf{Received:}~ {\l_cacdlore_received_tl}\hskip 5em
  \textbf{Revised:}~ {\l_cacdlore_revised_tl}\hskip 5em
  \textbf{Accepted:}~ {\l_cacdlore_accepted_tl}\par \vskip 10pt
  \fi
  \ifAPA
    \l__citation_styleb:
  \else
    \l__citation_stylea:
  \fi
  \par\vskip 10pt
  \hcoffin_set:Nn \l__CreativeCommons_coffin { \faCreativeCommons }
  \vcoffin_set:Nnn \l__title_coffin {\linewidth - 8mm - \coffin_wd:N \l__CreativeCommons_coffin} {\fontsize{8pt}{8pt}\selectfont \parbox{\linewidth}{\l_cacdlore_copyright_tl} }
  \coffin_scale:Nnn \l__CreativeCommons_coffin {1.6}{1.6}
  \coffin_join:NnnNnnnn
  \l__CreativeCommons_coffin {r}{vc}
  \l__title_coffin {l}{vc}
  {\linewidth  - \coffin_wd:N \l__CreativeCommons_coffin - \coffin_wd:N \l__title_coffin }{0pt}
  \coffin_typeset:Nnnnn \l__CreativeCommons_coffin {l}{t}{0pt}{7pt}\par \vskip 10pt
  \textbf{Abstract:}~ \l_cacdlore_abstract_tl\par \vskip 10pt
  \textbf{Keywords:}~ \l_cacdlore_keywords_tl\par \vskip 4pt
  \endgroup
  \if@linenumberon
  \linenumbers
  \fi
}

\cs_set_eq:NN \maketitle \__maketitle:

\titleformat{\section}{\bfseries\fontsize{10pt}{10pt}\selectfont}
{\thesection}{.8em}{}
\titleformat{\subsection}{\bfseries\fontsize{10pt}{10pt}\selectfont}
{\thesubsection}{.8em}{}
\titleformat{\subsubsection}{\fontsize{10pt}{10pt}\selectfont}
{\thesubsubsection}{.8em}{}

\titlespacing*{\section}{0pt}{1em  plus 1ex minus .2ex}{.5em  plus .2ex}
\titlespacing*{\subsection}{0pt}{1em  plus 1ex minus .2ex}{.5em  plus .2ex}
\titlespacing*{\subsubsection}{0pt}{.6em  plus 1ex minus .2ex}{.3em  plus .2ex}

\ExplSyntaxOff

\RequirePackage{hyperref}

\hypersetup{
  hidelinks,
  bookmarksnumbered  = true,
  bookmarksopen      = true,
  bookmarksopenlevel = 2,
  colorlinks         = true,
  citecolor          = citecolor,
  linkcolor          = citecolor,
  urlcolor           = black,
  breaklinks         = false,
  backref            = false,
}

\endinput
